Django Frontend Static — django-frontend-static 1.1.1 documentation

### Navigation

- index
- next |
- django-frontend-static 1.1.1 documentation »

# Django Frontend Static

A basic Django application to install often used static files.

With the convenience of an installable Django application, easily add some of the most widely used static files.

There are no templates included. If you want a skeleton application built on HTML5 Boilerplate and Twitter Bootstrap then checkout django-frontend-skeleton. If you want a light-weight template built on HTML5 Boilerplate without any static files then check out django-frontend-template.

Package: | https://pypi.python.org/pypi/django-frontend-static
Source: | https://github.com/jonfaustman/django-frontend-static

## Sunsetting

Django Frontend Static is sunsetting. After two more release cycles it will ofically be discontinued. Please transition to django-frontend.

While continuing to use Django Frontend Static, be sure to force upgrade to avoid namespacing issues.

Read this article for more information.

### Starring

- HTML5 Boilerplate (based on 4.2.0)
- Modernizr (2.6.2)
- jQuery (1.10.2) and (2.0.3)
- jQuery UI (1.10.3)
- jQuery DataTables (1.9.4)
- jQuery Dynamic Formset (1.2)
- jQuery Smooth Scroll (1.4.11)
- Twitter Bootstrap (3.0.0 RC1)
- iOS-Orientationchange-Fix
- famfamfam’s Silk Icons

### Contents

- Getting Started
  - Install
- Template tags
  - djfrontend
- Optional Settings
  - DJFRONTEND_STATIC_URL
  - DJFRONTEND_GA_SETDOMAINNAME
  - DJFRONTEND_GA_SETALLOWLINKER
- License
  - Component Specific Licenses
- Changelog
  - 1.1.0
  - 1.0.1
  - 1.0.0
  - 0.1.0
- Road Map
  - 1.*.0

### Navigation

- index
- next |
- django-frontend-static 1.1.1 documentation »